import sys
from runpy import run_module
from netdisco.util.perl import marshal_for_perl


def main():
    target = ['netdisco', 'worklet']

    if len(sys.argv) > 1:
        target.extend(sys.argv[1:])
    else:
        raise Exception('missing worklet name to runner')

    gd = run_module('.'.join(target), run_name='__main__')
    retval = marshal_for_perl(gd['c'] if 'c' in gd else gd['context'] if 'context' in gd else None)
    print(retval)


if __name__ == '__main__':
    main()



"""
netdisco.util.status
~~~~~~~~~~~~~~~~~~~~

This module provides a Status class which models the return code and message
of a Python worklet along with convenience methods to set the status. A fresh
instance of the Status class has an empty message and null (empty string) message.
"""

from dataclasses import dataclass, field


@dataclass(frozen=True)
class StatusManager:
    status: str = ''
    log: str = ''

    def is_ok(self) -> bool:
        return True if self.status == 'done' else False

    def not_ok(self) -> bool:
        return not self.is_ok()

    def level(self) -> int:
        return (
            4
            if self.status == 'error'
            else 3
            if self.status == 'done'
            else 2
            if self.status == 'defer'
            else 1
            if self.status == 'info'
            else 0
        )

    def error(self, msg):
        self.status = 'error'
        self.log = msg

    def done(self, msg):
        self.status = 'done'
        self.log = msg

    def defer(self, msg):
        self.status = 'defer'
        self.log = msg

    def info(self, msg):
        self.status = 'info'
        self.log = msg

status = StatusManager()


"""
netdisco.util.stash
~~~~~~~~~~~~~~~~~~~

Access to Netdisco vars() stash.
"""

import os
import json
from dataclasses import dataclass, field

ND2_VARS = json.loads(os.environ['ND2_VARS'])

@dataclass(frozen=True)
class StashManager:
    store: dict = field(default_factory=dict)

    def get(self, key):
        return ND2_VARS[key] or self.store[key]

    def set(self, key, val):
        self.store[key] = val

stash = StashManager()